@@ -12,7 +12,7 @@ const char *config_esmtphelo()
 {
 	if (!helohost)
 	{
-	char	*f=config_search("esmtphelo");
+	char	*f=config_localfilename("esmtphelo");
 
 		if ((helohost=config_read1l(f)) == 0)
 			helohost=config_me();
