@@ -31,7 +31,7 @@
 #include	"comcargs.h"
 #include	"comsubmitclient.h"
 #include	"comreadtime.h"
-#include	"rfc822.h"
+#include	"rfc822/rfc822.h"
 #include	"waitlib/waitlib.h"
 #include	"esmtpiov.h"
 #include	"esmtpconfig.h"
@@ -1278,15 +1278,23 @@ int	authenticated=0;
 		char	*buf=strcpy(courier_malloc(strlen(line)+1), line);
 		char	*authtype;
 		char	*authdata;
-		char    fakecmd[5];
+		char    fakecmd[80];
 
-		        strcpy(fakecmd, "AUTH");
+		        strcpy(fakecmd, "AUTH ");
 
 			starttls=0;
 			(void)strtok(buf, " \t\r\n");
 			authmethod=strtok(0, " \t\r\n");
+
+			strncat(fakecmd, authmethod, 20);
 			initreply=strtok(0, " \t\r\n");
 
+			if (initreply)
+			{
+				strcat(fakecmd, " ");
+				strncat(fakecmd, initreply, 20);
+			}
+
 			if (tls && (q=getenv("ESMTPAUTH_TLS")) != 0 && *q)
 				;
 			else
@@ -1330,11 +1338,22 @@ int	authenticated=0;
 						    auth_callback_func,
 						    authmethod);
 
+				if (rc)
+				{
+					char *p=auth_sasl_extract_userid(authtype, authdata);
+
+					if (p)
+					{
+						strcat(fakecmd, " ");
+						strncat(fakecmd, p,
+							sizeof(fakecmd)
+							-strlen(fakecmd)-1);
+						free(p);
+					}
+					strcpy(authuserbuf, "");
+				}
 				free(authtype);
 				free(authdata);
-
-				if (rc)
-					strcpy(authuserbuf, "");
 			}
 
 			if (authuserbuf[0] == 0)
